==> manydhcp2.5.2.tar.bz2: manydhcp/service/doublefrm.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  if(!isset($title)) $title = $TEXT['menu-btn27-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(!isset($button)) $button = $TEXT['btn_run'];
  if(!isset($action)) $action = "double.php";

?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post >
<table align="center" class="table" border="0" cellpadding="0" cellspacing="0" width="45%">
<tr>
    <td class="bold_it_page" ><?php echo $TEXT['srv-name']; ?>:&nbsp;</td>
    <td width="10%"><select name="srv_id">
    <?php
        $query1 = "SELECT srv_id, name, descr FROM `tbl_srv` ORDER BY name";
        $srv_tmp = mysql_query($query1);
          if(!$srv_tmp) {puterror($result2['skin'],$TEXT['error-tbl1']); require_once "../utils/bottom_adm.php"; exit();}
              while($srv = mysql_fetch_array($srv_tmp,MYSQL_ASSOC))
                {
                 if(trim($srv['descr']) == '')
                   {
                   $chk = "<option selected value=".$srv['srv_id'].">".$srv['name'];
                   }
                 else $chk = "<option value=".$srv['srv_id'].">".$srv['name']."(".$srv['descr'].")";
                 echo $chk;
                }
    ?>
    </select></td>
    <td><input type=checkbox name=srv_ch checked><?php echo $TEXT['login-all']; ?></td>
</tr>
<tr>
    <td colspan="2" class="bold_it_page" ><input class="button" type=submit value='<?php echo $button; ?>'></td>
    <td></td>
</tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/service/doublefrm.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['menu-btn27-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_run'];
  $action = "double.php";
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post >
<table align="center" class="table" border="0" cellpadding="0" cellspacing="0" width="50%">
<tr>
    <td class="bold_it_page" ><?php echo $TEXT['srv-name']; ?>:&nbsp;</td>
    <td width="10%"><select name="srv_id">
    <?php
        $query1 = "SELECT srv_id, name, descr FROM `tbl_srv` ORDER BY name";
        $srv_tmp = mysqli_query($dbcnx,$query1);
          if(!$srv_tmp) {puterror($result2['skin'],$TEXT['error-tbl1']); require_once "../utils/bottom_adm.php"; exit();}
              while($srv = mysqli_fetch_array($srv_tmp,MYSQLI_ASSOC))
                {
                 if(trim($srv['descr']) == '')
                   {
                   $chk = "<option selected value=".$srv['srv_id'].">".$srv['name'];
                   }
                 else {$chk = "<option value=".$srv['srv_id'].">".$srv['name']."(".$srv['descr'].")";}
                 echo $chk;
                }
    ?>
    </select></td>
    <td><input type=checkbox name=srv_ch checked><?php echo $TEXT['login-all']; ?></td>
</tr>
<tr>
    <td class="bold_it_page" ><?php echo $TEXT['srv-fltr']; ?>:&nbsp;</td>
    <td><input type="checkbox" name="srv_fltr"></td>
</tr>
<tr>
    <td colspan="2" class="bold_it_page" ><input class="button" type=submit value='<?php echo $button; ?>'></td>
    <td></td>
</tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
